==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/lang/korean.php <==
<?
define("_TOP5_DESC","    5");
define("_HOT5_DESC","    5");
define("_LASTC5_DESC","   5");
define("_STORY_EXT","  ũ ");
define("_STORY_LINK_INDEX","  ũ ε");
define("_STORY_LINK_INDEX_ADD","ε ߰ϱ");
define("_STORY_LINK_INDEX_KILL","ε  ش   ũ  ˴ϴ.");

define("_LINK_ANYONE","ũ   ( Ȯʿ)");
define("_LINK_ONLYADMIN","ڸ  ");
define("_LINK_FREE","ڰ Ӱ ũ  ");
# logs.php
define("_LOGS_NOTHING"," ϴ");
define("_LOGS_RESET"," ");

# layout.php
define("_LAYOUT_EDITOR","̾ƿ : ");
define("_LAYOUT_VIEW","/б");
define("_LAYOUT_KILL","");
define("_LAYOUT_ADD","߰/");
define("_LAYOUT_AUTHOR","ۼ");
define("_LAYOUT_DESC","");
define("_LAYOUT_BG","׶ ̹");
define("_LAYOUT_LOGO","ΰ ̹");
define("_LAYOUT_FONT","Ʈ ");
define("_LAYOUT_WIDTH"," ");

define("_LAYOUT_TITLE_COLOR"," ");
define("_LAYOUT_BLOCK_WIDTH"," ");
define("_LAYOUT_BLOCK_ALIGN","⺻  ");
define("_LAYOUT_THEME","׸ / ÷Ʈ");
define("_LAYOUT_B_LEFT"," ");
define("_LAYOUT_B_RIGHT"," ");
define("_LAYOUT_ADDED","̾ƿ  Ǿϴ.");
define("_NOTKILL","Ϸ ׸  ⺻׸ Ǿ Ƿ Ҽ ϴ.");

# for Log Messages
define("_UPDATE_STORY"," ");
define("_REPOST_STORY"," ");
define("_UPDATE_BLOCK"," ");
define("_UPDATE_REPLY"," ");
define("_UPDATE_TOPIC","з ");
define("_ADD_TOPIC","з ");
define("_ADD_POLL","ǥ ");
define("_ADD_BLOCK"," ߰");
define("_UPDATE_POLL","ǥ ");
define("_UPDATE_CATE","ũ з ");
define("_LOG_RESET","α ");
define("_UPDATE_LAYOUT","̾ƿ ");
define("_DELETE_LAYOUT","̾ƿ ");
define("_UPDATE_SITE","Ʈ ⺻  ");
define("_UPDATE_STORY_CONF","  ");
define("_UPDATE_REPLY_CONF","  ");
define("_UPDATE_EXT_CONF","Ȯ  ");
define("_DELETE_ITEM","");
define("_UNABLE_DEL","  ߻");
define("_DEL_POLL","ǥ ");
define("_DEL_TOPIC","з ");
define("_DEL_CATE","ũ з ");

# for Additional Control Page
define("_SHOW_PTIME"," ó ð ǥ");
define("_SHOW_NUM"," з ۰ ǥ");
define("_CATCH_REPLY","  ڰ ̸Ϸ ޾ƺ");
define("_FORM_WRAP","Է WRAP ");
define("_QP_ENCODE","߼۵Ǵ   ü QP ڵ");
define("_USE_THEME"," ׸ ");
define("_THEMES","ڰ  ִ ׸ ");
define("_ANTI_SPAM","  ");
define("_ANTI_SPAM2","۾  IP");
define("_ANTI_IP","  IP");
define("_BLOCK_IP_LIST","  IP ");
define("_SPAM_LIST"," ڿ  (regex)");
define("_BLOCK_LIST","۾  IP ");
define("_SHOW_CONTACT","ó ũ ǥ");
define("_CONT_ADD_TXT"," ø    (html )");
define("_LOGIN_AD_TXT","͸  α ڽ ǥõ  (html )");
define("_TOTAL_COUNT_IN_TOPIC","з  ü , ǥ");
define("_REPLY_HTML_PARSE_LEVEL"," html Ľ ");
define("_REPLY_PAGES"," ǥö  ");
define("_FILE_CACHE","RDF,URL,INCLUDE  ĳ Ϸ ó");
define("_SHOW_IP","/忡 ۾ IP ּҸ ǥ");
define("_ENABLE_BUTTON"," ϴܿ / ũ ǥ");
define("_ENABLE_DAY","  /¥ ǥ");
define("_REREPLY"," θ  ۾̿ Ϸ ");
define("_FEATURE_TITLE","Ư  ");
define("_UC_SCORE","α ڰ   ( ۼ)");
define("_RSS_POPWINDOW","rss  ũ Ŭ â ");

# topics.php
define("_TOPIC_IMAGE","̹");
define("_TOPIC_TITLE","");
define("_TOPIC_ALTTAG","ALT ±");
define("_TOPIC_RULE","");
define("_TOPIC_KILL","з Ǹ   / 嵵  ˴ϴ.");
define("_TOPIC_ADD"," з ߰");
define("_TOPIC_IMG_NULL","  ʽϴ.");
define("_TOPIC_NO_POST"," ø Ұ");
define("_TOPIC_NO_COMMENT"," Ұ");

# http referer
define("_REFER_LIMIT"," ");
define("_REFER_LIMIT_NO","");
define("_SHOW_ALL"," ");

# browser, os recored
define("_COUNTER","/OS  ()");
define("_TIME_COUNTER","ð  ");
define("_COUNT_INIT","ʱȭ ϱ");

# menu block
define("_MENU_BLOCK"," ޴  ġ");

# session
define("_SESSION","  (¶  Ȯ )");
define("_SESSION_TMOUT","<font size=\"-1\">ý  ð      Ǵ: ");
define("_SESSION_MIN","</font>");
define("_ONLY_SESSION","(<a href=\"user-ext.php\"> </a>   쿡 ۵մϴ.)");

# private msg
define("_PRIVATE_MSG","  ");
define("_PRIV_MSG_LIMIT","ִ   ");

# user
define("_LEVEL","");
define("_NORMAL_USER","Ϲ ");
define("_MODERATOR","");
define("_SCORE_MODERATOR"," ");
define("_TOTAL","ü");
define("_USER_ADMIN"," ");
define("_USER_ADD","");
define("_USER_FIND","ã");
define("_USER_EDIT","");
define("_USER_KILL","");
define("_SENDMAIL"," ڿ ̸ ");
define("_UPDATED_USERDB","   ߽ϴ.");
define("_USER_ADDED","ڸ  ߽ϴ.");
define("_USER_DELETED","ڸ  ߽ϴ.");

# submit log
define("_UPDATED","");

define("_MORECONFIG","߰");

# user-ext
define("_ONLINE_USER_INFO_DISPLAY","¶   ǥ");
define("_STORY_WATCH","  ");
define("_REGIST_METHOD"," Ͻ ̸ ּ ȿ Ȯ");
define("_USER_IMG"," Ȩ ̹");
define("_COOKIE_TIME"," α Ű ȿ Ⱓ");
define("_DAY","");

define("_STORY_WATING"," ");
define("_NO_PROGRAM_STORY","α׷  ϴ.");
define("_AUTO_STORY"," ");
define("_STORY_PROGRAM","   ð ");
define("_PROGRAM_SAVED","  Ǿϴ.");
define("_CURRENT_TIME"," ð");
define("_YEAR","");
define("_UMONTH","");
define("_HOUR","");
define("_MINUTE","");
define("_POSTING_TIME"," ð");
define("_STORY_PROGRAM_EDITED","   Ǿϴ.");
define("_STORY_PROGRAM_DELETED","  ߽ϴ.");

define("_BMARK_LIMIT","å  ");

# admin_msg.php
define("_ADMIN_MSG"," ˸ ޼");
define("_ADMIN_MSG_EDIT","");
define("_ADMIN_MSG_ADD","߰");
define("_DISPLAY","ǥ ");
define("_ACTIVE","ǥ");
define("_INACTIVE","");
define("_DISPLAY_TYPE","ǥ ");
define("_EXPIRE","");
define("_CONTENT","");

define("_COPYRIGHT","۱");
define("_NOLOGIN_USER","α    ");

# sql.php
define("_PHP_INFO","PHP  ");
define("_SQL_RUNTIME","Ÿ  ");
define("_SQL_SYSTEM_VAR","ý  ");
define("_SQL_PROCESS","μ ");
define("_SQL_CHECK_TABLE","̺ Ȯ");
define("_SQL_REPAIR_TABLE","̺ ");
define("_SQL_OPTIMIZE_TABLE","̺ Ƽ");
define("_SQL_BACKUP_TABLE","ͺ̽ ");
define("_SQL_DOCUMENT","");
define("_SQL_ADMIN","ͺ̽ ");

# navigator.php
define("_NAVIGATOR","޴ ");
define("_NAVIG_TOP"," ũ");
define("_NAVIG_BLOCK"," ޴ ");
define("_NAVIG_MOVE","̵");
define("_NAVIG_NAME","ũ");
define("_NAVIG_ORDER","");
define("_NAVIG_ADD","ܺ ũ ߰");
define("_NAVIG_EDIT","ܺ ũ ");
define("_NAVIG_DISPLAY_NAME","ũ ̸");
define("_NAVIG_URL","Url");

# faq.php
define("_NEW_FAQ"," FAQ ");
define("_FAQ_TITLE","FAQ ");
define("_ADD_QA","/亯 ߰ϱ");
define("_EDIT_QA","/亯 ϱ");
define("_EDIT_FAQ","FAQ  ");

# htmltag.php
define("_HTML_OPTION","HTML ± ");
define("_HTML_OPTION1","ּ Ѱ ̻ ±׸ ؾ մϴ.");

# config-story.php
define("_HTML_PARSE_LEVEL","⺻ HTML Ľ ");
define("_RDF_USE","RSS   ");
define("_MAILING_USE","ϸ Ʈ ");
define("_USER_PARSE","ڰ Ľ  ");
define("_EXPORT_RDF_NOW","RSS  ٽ ");
define("_EXPORT_RDF_NOW1","RSS  ϴ.");
define("_THUMBNAIL"," ");
define("_IMAGICK","Imagick α׷   ( /usr/bin/convert)");
define("_MAX_PIC_PIXEL","÷ε ̹ (jpg,gif,png) ũⰡ    Ǵ (ȼ )  ũ  ϴ.");
define("_THUMB_SIZE"," ũ⸦  մϴ (, ȼ )");
define("_NO_IMAGICK","convert   ã  ϴ!");

# polls.php
define("_POLL_QUES","");
define("_POLL_ADD","ǥ ߰ϱ");
define("_POLL_DISP","ǥ ġ");
define("_POLL_EXPIRE","Ű ");
define("_POLL_ANSWER","亯");

# random_link.php
define("_RANDOM_LINK_ADD","ũ ߰");
define("_RANDOM_LINK_EDIT","ũ ");
define("_RANDOM_LINK_TITLE","ũ ̸");
define("_RANDOM_LINK_NUMS","ѹ ǥ ũ ");
define("_RANDOM_LINK_HEAD"," ũ  ");
define("_RANDOM_LINK_SOURCE","ũ ҽ");
define("_RLINK_PREF1"," Է");
define("_RLINK_PREF2","ũ ");
define("_RLINK_PREF3","  ũ");

# random_button.php
define("_RANDOM_BUTTON_ADD","ư ߰");
define("_RANDOM_BUTTON_EDIT","ư ");
define("_RANDOM_BUTTON_ALT","Alt ");
define("_RANDOM_BUTTON_NUMS","ѹ ǥ ư ");
define("_RANDOM_BUTTON_HEAD"," ư  ");

# banners.php
define("_BANNER","");
define("_BANNER_LOCATION"," ǥ ġ");
define("_BANNER_LOCATION_DESC"," ׸ ÷Ʈ  \"header.tmpl\", Ǵ \"footer.tmpl\" Ͽ \"\$banner\"  ߰ؾ մϴ.");
define("_BANNER_ALT","ALT ");
define("_BANNER_ADD"," ߰");
define("_BANNER_EDIT"," ");

# blocks.php
define("_BLOCK_STORY_ONLY","  ǥ");
define("_BLOCK_RDF_SUPP","RSS/RDF  մϴ.");
define("_BLOCK_INCLUDE","URL Ǵ PATH");
define("_BLOCK_CACHE","ĳ ");
define("_BLOCK_CACHE_DESC"," / 0 ĳ ");
define("_NOT_URL","Url Ǵ    ϴ");
define("_MAX_ITEMS","ִ ũ ");

# config-site.php
define("_UNIQUEKEY"," ");
define("_KEYDESC","Korweblog ó ġߴٸ ݵ Ͽ մϴ.");

# config-new.php
define("_STORY_LST","͸   б⸦   Rid");

# user-mail.php
define("_ALL","ü");
define("_MAIL_SEND","");
define("_GROUP_MAIL","׷  ");
define("_GROUP"," ׷");
define("_SENDMAIL_WARN","ڰ   ð  ҿ   ֽϴ. \"\" ư ð  ȭ Ÿ  ٸž մϴ. ư  ų  ϸ  ۿ    ֽϴ.");

# lost files (attachment.php)
define("_LOST_FILES"," ");
define("_LOST_FILES_DESC","ýۿ ÷  Խù ų, Խù ÷ε  ýۿ  ʴ  ϵ մϴ.");
define("_LOST_FILES1"," ýۻ  ʴ ");
define("_LOST_FILES2","ýۿ   ÷ε  ");
define("_LOST_FILES_DEL"," ϱ");

# trackback msg
define("_TBMSG_LENGTH","Ʈ ޽  ");
define("_TBMSG_SHOW","Ʈ ޽  Բ ǥ");
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/admin/lang/korean.php <==
<?
define("_TOP5_DESC","    5");
define("_HOT5_DESC","    5");
define("_LASTC5_DESC","    5");
define("_STORY_EXT","  ũ ");
define("_STORY_LINK_INDEX","  ũ ε");
define("_STORY_LINK_INDEX_ADD","ε ߰ϱ");
define("_STORY_LINK_INDEX_KILL","ε  ش   ũ ˴ϴ.");

define("_LINK_ANYONE","ũ   ( Ȯʿ)");
define("_LINK_ONLYADMIN","ڸ  ");
define("_LINK_FREE","ڰ Ӱ ũ  ");
# logs.php
define("_LOGS_NOTHING"," ϴ");
define("_LOGS_RESET"," ");

# layout.php
define("_LAYOUT_EDITOR","̾ƿ : ");
define("_LAYOUT_VIEW","/б");
define("_LAYOUT_KILL","");
define("_LAYOUT_ADD","߰/");
define("_LAYOUT_AUTHOR","ۼ");
define("_LAYOUT_DESC","");
define("_LAYOUT_BG","׶ ̹");
define("_LAYOUT_LOGO","ΰ ̹");
define("_LAYOUT_FONT","Ʈ ");
define("_LAYOUT_WIDTH"," ");

define("_LAYOUT_TITLE_COLOR"," ");
define("_LAYOUT_BLOCK_WIDTH"," ");
define("_LAYOUT_BLOCK_ALIGN","⺻  ");
define("_LAYOUT_THEME","׸/ø");
define("_LAYOUT_B_LEFT"," ");
define("_LAYOUT_B_RIGHT"," ");
define("_LAYOUT_ADDED","̾ƿ  Ǿϴ.");
define("_NOTKILL","Ϸ ׸  ⺻׸ Ǿ Ƿ   ϴ.");

# for Log Messages
define("_UPDATE_STORY"," ");
define("_REPOST_STORY"," ");
define("_UPDATE_BLOCK"," ");
define("_UPDATE_REPLY"," ");
define("_UPDATE_TOPIC","з ");
define("_ADD_TOPIC"," з ");
define("_ADD_POLL","ǥ ");
define("_ADD_BLOCK"," ߰");
define("_UPDATE_POLL","ǥ ");
define("_UPDATE_CATE","ũ з ");
define("_LOG_RESET","α ");
define("_UPDATE_LAYOUT","̾ƿ ");
define("_DELETE_LAYOUT","̾ƿ ");
define("_UPDATE_SITE","Ʈ ⺻  ");
define("_UPDATE_STORY_CONF","  ");
define("_UPDATE_REPLY_CONF","  ");
define("_UPDATE_EXT_CONF","Ȯ  ");
define("_DELETE_ITEM","");
define("_UNABLE_DEL","  ߻");
define("_DEL_POLL","ǥ ");
define("_DEL_TOPIC","з ");
define("_DEL_CATE","ũ з ");

# for Additional Control Page
define("_SHOW_PTIME"," ó ð ǥ");
define("_SHOW_NUM"," з ۰ ǥ");
define("_CATCH_REPLY","  ڰ E-Mail ޾ƺ");
define("_FORM_WRAP","Է WRAP ");
define("_QP_ENCODE","߼۵Ǵ   ü QP ڵ");
define("_USE_THEME"," ׸ ");
define("_THEMES","ڰ   ִ ׸ ");
define("_ANTI_SPAM","  ");
define("_ANTI_SPAM2","۾  IP");
define("_ANTI_IP","  IP");
define("_BLOCK_IP_LIST","  IP ");
define("_SPAM_LIST"," ڿ  (regex)");
define("_BLOCK_LIST","۾  IP ");
define("_SHOW_CONTACT","ó ũ ǥ");
define("_CONT_ADD_TXT"," ø    (HTML )");
define("_LOGIN_AD_TXT","͸  α ڽ ǥõ  (HTML )");
define("_TOTAL_COUNT_IN_TOPIC","з  ü ,   ǥ");
define("_REPLY_HTML_PARSE_LEVEL"," HTML Ľ ");
define("_REPLY_PAGES"," ǥö  ");
define("_FILE_CACHE","RSS, RDF, URL, INCLUDE  ĳ Ϸ ó");
define("_SHOW_IP","/忡 ۾ IP ּҸ ǥ");
define("_ENABLE_BUTTON"," ϴܿ / ũ ǥ");
define("_ENABLE_DAY","  /¥ ǥ");
define("_REREPLY"," θ  ۾̿ Ϸ ");
define("_FEATURE_TITLE","Ư  ");
define("_UC_SCORE","α ڰ    ( ۼ)");
define("_RSS_POPWINDOW","RSS  ũ Ŭ â ");
define("_RSS_BUTTON","RSS ̹ ư ǥ");

# topics.php
define("_TOPIC_IMAGE","̹");
define("_TOPIC_TITLE","");
define("_TOPIC_ALTTAG","ALT ±");
define("_TOPIC_RULE","");
define("_TOPIC_KILL","з Ǹ   / 嵵 ˴ϴ.");
define("_TOPIC_ADD"," з ߰");
define("_TOPIC_IMG_NULL","  ʽϴ.");
define("_TOPIC_NO_POST"," ø Ұ");
define("_TOPIC_NO_COMMENT"," Ұ");

# http referer
define("_REFER_LIMIT"," ");
define("_REFER_LIMIT_NO","");
define("_SHOW_ALL"," ");

# browser, os recored
define("_COUNTER","/OS  ()");
define("_TIME_COUNTER","ð  ");
define("_COUNT_INIT","ʱȭ ϱ");

# menu block
define("_MENU_BLOCK"," ޴  ġ");

# session
define("_SESSION","  (¶  Ȯ )");
define("_SESSION_TMOUT","<font size=\"-1\">ý  ð      Ǵ: ");
define("_SESSION_MIN","</font>");
define("_ONLY_SESSION","(<a href=\"user-ext.php\"> </a>   쿡 ۵մϴ.)");

# private msg
define("_PRIVATE_MSG","  ");
define("_PRIV_MSG_LIMIT","ִ   ");

# user
define("_LEVEL","");
define("_NORMAL_USER","Ϲ ");
define("_MODERATOR","");
define("_SCORE_MODERATOR"," ");
define("_TOTAL","ü");
define("_USER_ADMIN"," ");
define("_USER_ADD","");
define("_USER_FIND","ã");
define("_USER_EDIT","");
define("_USER_KILL","");
define("_SENDMAIL","  ڿ E-Mail ");
define("_UPDATED_USERDB","  ߽ϴ.");
define("_USER_ADDED","ڸ ߽ϴ.");
define("_USER_DELETED","ڸ ߽ϴ.");

# submit log
define("_UPDATED","");

define("_MORECONFIG","߰");

# user-ext
define("_ONLINE_USER_INFO_DISPLAY","¶   ǥ");
define("_STORY_WATCH","  ");
define("_REGIST_METHOD"," Ͻ E-Mail ּ ȿ Ȯ");
define("_USER_IMG"," Ȩ ̹");
define("_COOKIE_TIME"," α Ű ȿ Ⱓ");
define("_DAY","");

define("_STORY_WATING"," ");
define("_NO_PROGRAM_STORY","α׷   ϴ.");
define("_AUTO_STORY"," ");
define("_STORY_PROGRAM","   ð ");
define("_PROGRAM_SAVED"," Ǿϴ.");
define("_CURRENT_TIME"," ð");
define("_YEAR","");
define("_UMONTH","");
define("_HOUR","");
define("_MINUTE","");
define("_POSTING_TIME"," ð");
define("_STORY_PROGRAM_EDITED","  Ǿϴ.");
define("_STORY_PROGRAM_DELETED"," ߽ϴ.");

define("_BMARK_LIMIT","å  ");

# admin_msg.php
define("_ADMIN_MSG"," ˸ ޽");
define("_ADMIN_MSG_EDIT","");
define("_ADMIN_MSG_ADD","߰");
define("_DISPLAY","ǥ ");
define("_ACTIVE","ǥ");
define("_INACTIVE","");
define("_DISPLAY_TYPE","ǥ ");
define("_EXPIRE","");
define("_CONTENT","");

define("_COPYRIGHT","۱");
define("_NOLOGIN_USER","α    ");

# sql.php
define("_PHP_INFO","PHP  ");
define("_SQL_RUNTIME","Ÿ  ");
define("_SQL_SYSTEM_VAR","ý  ");
define("_SQL_PROCESS","μ ");
define("_SQL_CHECK_TABLE","̺ Ȯ");
define("_SQL_REPAIR_TABLE","̺ ");
define("_SQL_OPTIMIZE_TABLE","̺ Ƽ");
define("_SQL_BACKUP_TABLE","ͺ̽ ");
define("_SQL_DOCUMENT","");
define("_SQL_ADMIN","ͺ̽ ");

# navigator.php
define("_NAVIGATOR","޴ ");
define("_NAVIG_TOP"," ũ");
define("_NAVIG_BLOCK"," ޴ ");
define("_NAVIG_MOVE","̵");
define("_NAVIG_NAME","ũ");
define("_NAVIG_ORDER","");
define("_NAVIG_ADD","ܺ ũ ߰");
define("_NAVIG_EDIT","ܺ ũ ");
define("_NAVIG_DISPLAY_NAME","ũ ̸");
define("_NAVIG_URL","URL");

# faq.php
define("_NEW_FAQ"," FAQ ");
define("_FAQ_TITLE","FAQ ");
define("_ADD_QA","/亯 ߰ϱ");
define("_EDIT_QA","/亯 ϱ");
define("_EDIT_FAQ","FAQ  ");

# htmltag.php
define("_HTML_OPTION","HTML ± ");
define("_HTML_OPTION1","ּ   ̻ ±׸ ؾ մϴ.");

# config-story.php
define("_USERONLY_POST"," ڿԸ  ø ");
define("_HTML_PARSE_LEVEL","⺻ HTML Ľ ");
define("_RDF_USE","RSS  ");
define("_MAILING_USE","ϸ Ʈ ");
define("_USER_PARSE","ڰ Ľ  ");
define("_EXPORT_RDF_NOW","RSS Cache  ٽ ");
define("_EXPORT_RDF_NOW1","RSS  ϴ.");
define("_THUMBNAIL"," ");
define("_IMAGICK","Imagick α׷   ( /usr/bin/convert)");
define("_MAX_PIC_PIXEL","÷ε ̹ (jpg, gif, png) ũⰡ    Ǵ (ȼ )  ũ  ϴ.");
define("_THUMB_SIZE"," ũ⸦  մϴ (, ȼ )");
define("_NO_IMAGICK","convert   ã  ϴ!");

# polls.php
define("_POLL_QUES","");
define("_POLL_ADD","ǥ ߰ϱ");
define("_POLL_DISP","ǥ ġ");
define("_POLL_EXPIRE","Ű ");
define("_POLL_ANSWER","亯");

# random_link.php
define("_RANDOM_LINK_ADD","ũ ߰");
define("_RANDOM_LINK_EDIT","ũ ");
define("_RANDOM_LINK_TITLE","ũ ̸");
define("_RANDOM_LINK_NUMS","ѹ ǥ ũ ");
define("_RANDOM_LINK_HEAD"," ũ  ");
define("_RANDOM_LINK_SOURCE","ũ ҽ");
define("_RLINK_PREF1"," Է");
define("_RLINK_PREF2","ũ ");
define("_RLINK_PREF3","  ũ");

# random_button.php
define("_RANDOM_BUTTON_ADD","ư ߰");
define("_RANDOM_BUTTON_EDIT","ư ");
define("_RANDOM_BUTTON_ALT","ALT ");
define("_RANDOM_BUTTON_NUMS","ѹ ǥ ư ");
define("_RANDOM_BUTTON_HEAD"," ư  ");

# banners.php
define("_BANNER","");
define("_BANNER_LOCATION"," ǥ ġ");
define("_BANNER_LOCATION_DESC"," ׸ ø  \"header.tmpl\", Ǵ \"footer.tmpl\" Ͽ \"\$banner\"  ߰ؾ մϴ.");
define("_BANNER_ALT","ALT ");
define("_BANNER_ADD"," ߰");
define("_BANNER_EDIT"," ");

# blocks.php
define("_BLOCK_STORY_ONLY","  ǥ");
define("_BLOCK_RDF_SUPP","RSS/RDF  մϴ.");
define("_BLOCK_INCLUDE","URL Ǵ PATH");
define("_BLOCK_CACHE","ĳ ");
define("_BLOCK_CACHE_DESC"," / 0 ĳ ");
define("_NOT_URL","URL Ǵ    ϴ");
define("_MAX_ITEMS","ִ ũ ");

# config-site.php
define("_UNIQUEKEY"," ");
define("_KEYDESC","KorWeblog ó ġߴٸ ݵ Ͽ մϴ.");

# config-new.php
define("_STORY_LST","͸   б⸦   Rid");

# user-mail.php
define("_ALL","ü");
define("_MAIL_SEND","");
define("_GROUP_MAIL","׷  ");
define("_GROUP"," ׷");
define("_SENDMAIL_WARN","ڰ   ð  ҿ  ֽϴ. \"\" ư ð  ȭ Ÿ  ٸž մϴ. ư   ų  ϸ  ۿ    ֽϴ.");

# lost files (attachment.php)
define("_LOST_FILES"," ");
define("_LOST_FILES_DESC","ýۿ ÷  Խù ų, Խù ÷ε  ýۿ  ʴ  ϵ մϴ.");
define("_LOST_FILES1"," ýۻ  ʴ ");
define("_LOST_FILES2","ýۿ   ÷ε  ");
define("_LOST_FILES_DEL"," ϱ");

# trackback msg
define("_TBMSG_LENGTH","Ʈ ޽  ");
define("_TBMSG_SHOW","Ʈ ޽  Բ ǥ");
define("_EXCERPT_PARSE_LEVEL","Ʈ ޽ Ľ ");
?>
